==> haskell-tamarin-prover-term-1.4.0-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-term.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-term
version: 1.4.0
id: tamarin-prover-term-1.4.0-FItiPGRkcON7bw1sXAf4N3
key: tamarin-prover-term-1.4.0-FItiPGRkcON7bw1sXAf4N3
license: LicenseRef-GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Term manipulation library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides term manipulation infrastructure
    (matching, unification, narrowing, finite variants) for
    the Tamarin prover. It uses maude
    (<http://maude.cs.uiuc.edu/>) as a backend for
    normalization, equational matching, and unification.
category: Theorem Provers
abi: 41b6810290d202b2220daf86ceb2d365
exposed: True
exposed-modules:
    Term.Builtin.Convenience Term.Builtin.Rules Term.Builtin.Signature
    Term.LTerm Term.Maude.Parser Term.Maude.Process
    Term.Maude.Signature Term.Maude.Types Term.Narrowing.Variants
    Term.Narrowing.Variants.Check Term.Narrowing.Variants.Compute
    Term.Positions Term.Rewriting.Definitions Term.Rewriting.Norm
    Term.Substitution Term.Subsumption Term.SubtermRule
    Term.Unification Term.UnitTests Term.VTerm
hidden-modules: Term.Term Term.Term.Classes Term.Term.Raw
                Term.Term.FunctionSymbols Term.Narrowing.Narrow
                Term.Substitution.SubstVFree Term.Substitution.SubstVFresh
import-dirs: /usr/lib/ghc-8.4.3/site-local/tamarin-prover-term-1.4.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/tamarin-prover-term-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tamarin-prover-term-1.4.0
hs-libraries: HStamarin-prover-term-1.4.0-FItiPGRkcON7bw1sXAf4N3
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ base-4.11.1.0
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.11.0
    deepseq-1.4.3.0 dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD mtl-2.2.2
    process-1.6.3.0 safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    tamarin-prover-utils-1.4.0-97YC04SUVLG5IGhfYLbjy8
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ=5fc61cc528c94bde8145f6cbd8ed3b00
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=d8185cdeb1f72c3606ef0c9fb78dc6d0
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             tamarin-prover-utils-1.4.0-97YC04SUVLG5IGhfYLbjy8=a6f5fa13011fee14a3ebdc93187c4875
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-term/html/tamarin-prover-term.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-term/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-term-1.4.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-term.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-term
version: 1.4.0
id: tamarin-prover-term-1.4.0-2exPKYqZkCwHsoVav7CWjS
key: tamarin-prover-term-1.4.0-2exPKYqZkCwHsoVav7CWjS
license: LicenseRef-GPL
copyright: Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018
maintainer: Simon Meier <simon.meier@inf.ethz.ch>,
            Jannik Dreier <research@jannikdreier.net>,
            Ralf Sasse <ralf.sasse@gmail.com>
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>,
        Jannik Dreier <research@jannikdreier.net>,
        Ralf Sasse <ralf.sasse@gmail.com>
homepage: https://tamarin-prover.github.io/
synopsis: Term manipulation library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides term manipulation infrastructure
    (matching, unification, narrowing, finite variants) for
    the Tamarin prover. It uses maude
    (<http://maude.cs.uiuc.edu/>) as a backend for
    normalization, equational matching, and unification.
category: Theorem Provers
abi: 60a3d77201082b98a501037d9c295345
exposed: True
exposed-modules:
    Term.Builtin.Convenience Term.Builtin.Rules Term.Builtin.Signature
    Term.LTerm Term.Maude.Parser Term.Maude.Process
    Term.Maude.Signature Term.Maude.Types Term.Narrowing.Variants
    Term.Narrowing.Variants.Check Term.Narrowing.Variants.Compute
    Term.Positions Term.Rewriting.Definitions Term.Rewriting.Norm
    Term.Substitution Term.Subsumption Term.SubtermRule
    Term.Unification Term.UnitTests Term.VTerm
hidden-modules: Term.Term Term.Term.Classes Term.Term.Raw
                Term.Term.FunctionSymbols Term.Narrowing.Narrow
                Term.Substitution.SubstVFree Term.Substitution.SubstVFresh
import-dirs: /usr/lib/ghc-8.4.3/site-local/tamarin-prover-term-1.4.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/tamarin-prover-term-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tamarin-prover-term-1.4.0
hs-libraries: HStamarin-prover-term-1.4.0-2exPKYqZkCwHsoVav7CWjS
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    attoparsec-0.13.2.2-66ub406fEYL5HI27KdshEC base-4.11.1.0
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.11.0
    deepseq-1.4.3.0 dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD mtl-2.2.2
    process-1.6.3.0 safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    tamarin-prover-utils-1.4.0-97YC04SUVLG5IGhfYLbjy8
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             attoparsec-0.13.2.2-66ub406fEYL5HI27KdshEC=c6a831664a8826b2c70f720ac226f7d1
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             binary-0.8.5.1=758db3c95031800de821949083b71c7f
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=d8185cdeb1f72c3606ef0c9fb78dc6d0
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             tamarin-prover-utils-1.4.0-97YC04SUVLG5IGhfYLbjy8=a6f5fa13011fee14a3ebdc93187c4875
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-term/html/tamarin-prover-term.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-term/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
